package Acme::PM::Barcelona;

use warnings;
use strict;

=head1 NAME

Acme::PM::Barcelona - Talks and projects by Barcelona.pm

=head1 VERSION

Version 0.03

=cut

our $VERSION = '0.03';


=head1 SYNOPSIS

This is a list of talks and projects made by Barcelona.pm as a group.

=head1 DETAILS

=head2 TALKS

=over 4

=item 19 Sep 2009 - Software Freedom Day

The talk L<Acme::PM::Barcelona::12x5_ca> consists in 12 subjects
presented in 5 minutes each, trying to attrack more people to our
Perl Mongers group, but mainly to Perl.

=back

=head2 PROJECTS

=over 4

=item Acme::PM::Barcelona::Meeting

A way of finding out when the next meeting will take place.

=back

=head1 AUTHOR

Alex Muntada, C<< <alexm at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-acme-pm-barcelona at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-PM-Barcelona>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Acme::PM::Barcelona


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Acme-PM-Barcelona>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Acme-PM-Barcelona>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Acme-PM-Barcelona>

=item * Search CPAN

L<http://search.cpan.org/dist/Acme-PM-Barcelona>

=back


=head1 ACKNOWLEDGEMENTS

Barcelona Perl Mongers

=head1 COPYRIGHT & LICENSE

Copyright 2009 Alex Muntada, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut

1; # End of Acme::PM::Barcelona
